# VishnuThinks Quiz

This is a simple Python quiz module that tests your knowledge of Python concepts.

## Installation

To install the module via pip:

pip install vishnuthinks

from vishnuthinks import run_quiz

run_quiz()